==> thinc-8.0.0a1-cp37-cp37m-win_amd64.whl: thinc/layers/__init__.py <==
# Weights layers
from .cauchysimilarity import CauchySimilarity
from .dropout import Dropout
from .embed import Embed
from .expand_window import expand_window
from .featureextractor import FeatureExtractor
from .hashembed import HashEmbed
from .layernorm import LayerNorm
from .linear import Linear
from .logistic import Logistic
from .maxout import Maxout
from .mish import Mish
from .multisoftmax import MultiSoftmax
from .parametricattention import ParametricAttention
from .pytorchwrapper import PyTorchWrapper, PyTorchRNNWrapper
from .relu import Relu
from .softmax import Softmax
from .sparselinear import SparseLinear
from .staticvectors import StaticVectors
from .lstm import LSTM, PyTorchLSTM
from .tensorflowwrapper import TensorFlowWrapper, keras_subclass
from .mxnetwrapper import MXNetWrapper

# Combinators
from .add import add
from .bidirectional import bidirectional
from .chain import chain
from .clone import clone
from .concatenate import concatenate
from .noop import noop
from .residual import residual
from .uniqued import uniqued
from .siamese import siamese

# Pooling
from .reduce_max import reduce_max
from .reduce_mean import reduce_mean
from .reduce_sum import reduce_sum

# Array manipulation
from .array_getitem import array_getitem

# Data-type transfers
from .list2array import list2array
from .list2ragged import list2ragged
from .list2padded import list2padded
from .ragged2list import ragged2list
from .padded2list import padded2list
from .remap_ids import remap_ids
from .strings2arrays import strings2arrays
from .with_array import with_array
from .with_flatten import with_flatten
from .with_padded import with_padded
from .with_list import with_list
from .with_ragged import with_ragged
from .with_reshape import with_reshape
from .with_getitem import with_getitem
from .with_debug import with_debug


__all__ = [
    "CauchySimilarity",
    "Linear",
    "Dropout",
    "Embed",
    "expand_window",
    "HashEmbed",
    "LayerNorm",
    "Maxout",
    "Mish",
    "MultiSoftmax",
    "ParametricAttention",
    "PyTorchWrapper",
    "PyTorchRNNWrapper",
    "Relu",
    "Softmax",
    "SparseLinear",
    "StaticVectors",
    "LSTM",
    "PyTorchLSTM",
    "TensorFlowWrapper",
    "add",
    "bidirectional",
    "chain",
    "clone",
    "concatenate",
    "noop",
    "residual",
    "uniqued",
    "siamese",
    "reduce_max",
    "reduce_mean",
    "reduce_sum",
    "list2array",
    "list2ragged",
    "list2padded",
    "ragged2list",
    "padded2list",
    "with_reshape",
    "with_getitem",
    "with_array",
    "with_list",
    "with_ragged",
    "with_padded",
    "with_flatten",
    "with_debug",
    "remap_ids",
]

==> thinc-8.1.3-cp37-cp37m-win_amd64.whl: thinc/layers/__init__.py <==
# Weights layers
from .cauchysimilarity import CauchySimilarity
from .dish import Dish
from .dropout import Dropout
from .embed import Embed
from .expand_window import expand_window
from .hashembed import HashEmbed
from .layernorm import LayerNorm
from .linear import Linear
from .lstm import LSTM, PyTorchLSTM
from .logistic import Logistic
from .maxout import Maxout
from .mish import Mish
from .multisoftmax import MultiSoftmax
from .parametricattention import ParametricAttention
from .pytorchwrapper import PyTorchWrapper, PyTorchWrapper_v2
from .pytorchwrapper import PyTorchRNNWrapper
from .relu import Relu
from .clipped_linear import ClippedLinear, ReluK, HardSigmoid, HardTanh
from .hard_swish import HardSwish
from .hard_swish_mobilenet import HardSwishMobilenet
from .swish import Swish
from .gelu import Gelu
from .resizable import resizable
from .sigmoid_activation import sigmoid_activation
from .sigmoid import Sigmoid
from .softmax_activation import softmax_activation
from .softmax import Softmax, Softmax_v2
from .sparselinear import SparseLinear
from .tensorflowwrapper import TensorFlowWrapper, keras_subclass
from .mxnetwrapper import MXNetWrapper

# Combinators
from .add import add
from .bidirectional import bidirectional
from .chain import chain
from .clone import clone
from .concatenate import concatenate
from .map_list import map_list
from .noop import noop
from .residual import residual
from .uniqued import uniqued
from .siamese import siamese
from .tuplify import tuplify

# Pooling
from .reduce_first import reduce_first
from .reduce_last import reduce_last
from .reduce_max import reduce_max
from .reduce_mean import reduce_mean
from .reduce_sum import reduce_sum

# Array manipulation
from .array_getitem import array_getitem

# Data-type transfers
from .list2array import list2array
from .list2ragged import list2ragged
from .list2padded import list2padded
from .ragged2list import ragged2list
from .padded2list import padded2list
from .remap_ids import remap_ids, remap_ids_v2
from .strings2arrays import strings2arrays
from .with_array import with_array
from .with_array2d import with_array2d
from .with_cpu import with_cpu
from .with_flatten import with_flatten
from .with_padded import with_padded
from .with_list import with_list
from .with_ragged import with_ragged
from .with_reshape import with_reshape
from .with_getitem import with_getitem
from .with_debug import with_debug
from .with_nvtx_range import with_nvtx_range
from .with_signpost_interval import with_signpost_interval


__all__ = [
    "CauchySimilarity",
    "Linear",
    "Dropout",
    "Embed",
    "expand_window",
    "HashEmbed",
    "LayerNorm",
    "LSTM",
    "Maxout",
    "Mish",
    "MultiSoftmax",
    "ParametricAttention",
    "PyTorchLSTM",
    "PyTorchWrapper",
    "PyTorchWrapper_v2",
    "PyTorchRNNWrapper",
    "Relu",
    "sigmoid_activation",
    "Sigmoid" "softmax_activation",
    "Softmax",
    "Softmax_v2",
    "SparseLinear",
    "TensorFlowWrapper",
    "add",
    "bidirectional",
    "chain",
    "clone",
    "concatenate",
    "noop",
    "residual",
    "uniqued",
    "siamese",
    "reduce_first",
    "reduce_last",
    "reduce_max",
    "reduce_mean",
    "reduce_sum",
    "resizable",
    "list2array",
    "list2ragged",
    "list2padded",
    "ragged2list",
    "padded2list",
    "with_reshape",
    "with_getitem",
    "with_array",
    "with_array2d",
    "with_cpu",
    "with_list",
    "with_ragged",
    "with_padded",
    "with_flatten",
    "with_debug",
    "with_nvtx_range",
    "with_signpost_interval",
    "remap_ids",
]
